@@ -335,6 +335,12 @@ func getConfigConsolidationTestCases() []configConsolidationTestCase {
 		{opts{cli: []string{"--system-tags", `""`}}, exp{}, func(t *testing.T, c Config) {
 			assert.Equal(t, metrics.SystemTagSet(0), *c.Options.SystemTags)
 		}},
+		{opts{env: []string{`K6_SYSTEM_TAGS=""`}}, exp{}, func(t *testing.T, c Config) {
+			assert.Equal(t, metrics.SystemTagSet(0), *c.Options.SystemTags)
+		}},
+		{opts{env: []string{`K6_SYSTEM_TAGS=proto,method`}}, exp{}, func(t *testing.T, c Config) {
+			assert.Equal(t, metrics.SystemTagSet(metrics.TagProto|metrics.TagMethod), *c.Options.SystemTags)
+		}},
 		{
 			opts{
 				runner: &lib.Options{
@@ -479,6 +485,16 @@ func getConfigConsolidationTestCases() []configConsolidationTestCase {
 			},
 			nil,
 		},
+		{
+			opts{
+				env: []string{"K6_PROFILING_ENABLED=true"},
+				cli: []string{"--profiling-enabled"},
+			},
+			exp{
+				consolidationError: false,
+			},
+			nil,
+		},
 		// TODO: test for differences between flagsets
 		// TODO: more tests in general, especially ones not related to execution parameters...
 	}
