@@ -10,7 +10,7 @@ func TestBuiltinOutputString(t *testing.T) {
 	t.Parallel()
 	exp := []string{
 		"cloud", "csv", "datadog", "experimental-prometheus-rw",
-		"influxdb", "json", "kafka", "statsd",
+		"influxdb", "json", "kafka", "statsd", "experimental-opentelemetry",
 	}
 	assert.Equal(t, exp, builtinOutputStrings())
 }
