@@ -1,5 +1,5 @@
-#!/bin/sh
-sha=926b0960d737b9f1dfd0ec0c1dfd95d836016d33 # this is just the commit it was last tested with
+#!/bin/sh -e
+sha=cb4a6c8074671c00df8cbc17a620c0f9462b312a # this is just the commit it was last tested with
 mkdir -p ./TestTC39/test262
 cd ./TestTC39/test262
 git init
