@@ -59,16 +59,16 @@ func (s Stage) MarshalJSON() ([]byte, error) {
 // UnmarshalText implements the encoding.TextUnmarshaler interface
 func (s *Stage) UnmarshalText(b []byte) error {
 	var stage Stage
-	parts := strings.SplitN(string(b), ":", 2)
-	if len(parts) > 0 && parts[0] != "" {
-		d, err := time.ParseDuration(parts[0])
+	durStr, targetStr, _ := strings.Cut(string(b), ":")
+	if durStr != "" {
+		d, err := time.ParseDuration(durStr)
 		if err != nil {
 			return err
 		}
 		stage.Duration = types.NullDurationFrom(d)
 	}
-	if len(parts) > 1 && parts[1] != "" {
-		t, err := strconv.ParseInt(parts[1], 10, 64)
+	if targetStr != "" {
+		t, err := strconv.ParseInt(targetStr, 10, 64)
 		if err != nil {
 			return err
 		}
