@@ -7,7 +7,7 @@ import (
 	"io"
 	"testing"
 
-	"github.com/jhump/protoreflect/desc/protoparse"
+	"github.com/jhump/protoreflect/desc/protoparse" //nolint:staticcheck // FIXME: #4035
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 	"google.golang.org/grpc"
@@ -64,6 +64,28 @@ func TestInvokeWithCallOptions(t *testing.T) {
 	assert.NotNil(t, res)
 }
 
+func TestInvokeWithDiscardResponseMessage(t *testing.T) {
+	t.Parallel()
+
+	reply := func(_, _ *dynamicpb.Message, opts ...grpc.CallOption) error {
+		assert.Len(t, opts, 3) // two by default plus one injected
+		return nil
+	}
+
+	c := Conn{raw: invokemock(reply)}
+	r := InvokeRequest{
+		Method:                 "/hello.HelloService/NoOp",
+		MethodDescriptor:       methodFromProto("NoOp"),
+		DiscardResponseMessage: true,
+		Message:                []byte(`{}`),
+		Metadata:               metadata.New(nil),
+	}
+	res, err := c.Invoke(context.Background(), r, grpc.UseCompressor("fakeone"))
+	require.NoError(t, err)
+	assert.NotNil(t, res)
+	assert.Nil(t, res.Message)
+}
+
 func TestInvokeReturnError(t *testing.T) {
 	t.Parallel()
 
@@ -153,7 +175,7 @@ func methodFromProto(method string) protoreflect.MethodDescriptor {
 			// otherwise the parser will try to parse "google/protobuf/descriptor.proto"
 			// with exactly the same name as the one we are trying to parse for testing
 			if filename != path {
-				return nil, nil
+				return nil, nil //nolint:nilnil
 			}
 
 			b := `
