@@ -9,6 +9,8 @@ import (
 	"time"
 
 	"github.com/sirupsen/logrus"
+	"gopkg.in/guregu/null.v3"
+
 	"go.k6.io/k6/cloudapi"
 	"go.k6.io/k6/errext"
 	"go.k6.io/k6/lib"
@@ -17,11 +19,12 @@ import (
 	"go.k6.io/k6/output"
 	cloudv2 "go.k6.io/k6/output/cloud/expv2"
 	"go.k6.io/k6/usage"
-	"gopkg.in/guregu/null.v3"
 )
 
-// TestName is the default k6 Cloud test name
-const TestName = "k6 test"
+const (
+	defaultTestName = "k6 test"
+	testRunIDKey    = "K6_CLOUDRUN_TEST_RUN_ID"
+)
 
 // versionedOutput represents an output implementing
 // metrics samples aggregation and flushing to the
@@ -119,7 +122,7 @@ func newOutput(params output.Params) (*Output, error) {
 		conf.Name = null.StringFrom(filepath.Base(scriptPath))
 	}
 	if conf.Name.String == "-" {
-		conf.Name = null.StringFrom(TestName)
+		conf.Name = null.StringFrom(defaultTestName)
 	}
 
 	duration, testEnds := lib.GetEndOffset(params.ExecutionPlan)
@@ -147,6 +150,7 @@ func newOutput(params output.Params) (*Output, error) {
 		duration:      int64(duration / time.Second),
 		logger:        logger,
 		usage:         params.Usage,
+		testRunID:     params.RuntimeOptions.Env[testRunIDKey],
 	}, nil
 }
 
@@ -178,6 +182,9 @@ func validateRequiredSystemTags(scriptTags *metrics.SystemTagSet) error {
 func (out *Output) Start() error {
 	if out.config.PushRefID.Valid {
 		out.testRunID = out.config.PushRefID.String
+	}
+
+	if out.testRunID != "" {
 		out.logger.WithField("testRunId", out.testRunID).Debug("Directly pushing metrics without init")
 		return out.startVersionedOutput()
 	}
@@ -192,7 +199,7 @@ func (out *Output) Start() error {
 	testRun := &cloudapi.TestRun{
 		Name:       out.config.Name.String,
 		ProjectID:  out.config.ProjectID.Int64,
-		VUsMax:     int64(lib.GetMaxPossibleVUs(out.executionPlan)),
+		VUsMax:     int64(lib.GetMaxPossibleVUs(out.executionPlan)), //nolint:gosec
 		Thresholds: thresholds,
 		Duration:   out.duration,
 		Archive:    out.testArchive,
