@@ -20,6 +20,7 @@ import (
 	"go.k6.io/k6/metrics"
 	"go.k6.io/k6/output"
 	cloudv2 "go.k6.io/k6/output/cloud/expv2"
+	"go.k6.io/k6/usage"
 	"gopkg.in/guregu/null.v3"
 )
 
@@ -94,13 +95,14 @@ func TestOutputCreateTestWithConfigOverwrite(t *testing.T) {
 	handler := func(w http.ResponseWriter, r *http.Request) {
 		switch r.URL.Path {
 		case "/v1/tests":
-			fmt.Fprintf(w, `{
+			_, err := fmt.Fprintf(w, `{
 "reference_id": "12345",
 "config": {
 	"metricPushInterval": "10ms",
 	"aggregationPeriod": "40s"
 }
 }`)
+			require.NoError(t, err)
 		case "/v1/tests/12345":
 			w.WriteHeader(http.StatusOK)
 		default:
@@ -120,6 +122,7 @@ func TestOutputCreateTestWithConfigOverwrite(t *testing.T) {
 			SystemTags: &metrics.DefaultSystemTagSet,
 		},
 		ScriptPath: &url.URL{Path: "/script.js"},
+		Usage:      usage.New(),
 	})
 	require.NoError(t, err)
 	require.NoError(t, out.Start())
@@ -146,6 +149,7 @@ func TestOutputStartVersionError(t *testing.T) {
 			"K6_CLOUD_API_VERSION": "99",
 		},
 		ScriptPath: &url.URL{Path: "/script.js"},
+		Usage:      usage.New(),
 	})
 	require.NoError(t, err)
 
@@ -169,6 +173,7 @@ func TestOutputStartVersionedOutputV2(t *testing.T) {
 			AggregationPeriod:  types.NullDurationFrom(1 * time.Hour),
 			MetricPushInterval: types.NullDurationFrom(1 * time.Hour),
 		},
+		usage: usage.New(),
 	}
 
 	o.client = cloudapi.NewClient(
@@ -189,6 +194,7 @@ func TestOutputStartVersionedOutputV1Error(t *testing.T) {
 		config: cloudapi.Config{
 			APIVersion: null.IntFrom(1),
 		},
+		usage: usage.New(),
 	}
 
 	err := o.startVersionedOutput()
@@ -216,6 +222,7 @@ func TestOutputStartWithTestRunID(t *testing.T) {
 			SystemTags: &metrics.DefaultSystemTagSet,
 		},
 		ScriptPath: &url.URL{Path: "/script.js"},
+		Usage:      usage.New(),
 	})
 	require.NoError(t, err)
 	require.NoError(t, out.Start())
