@@ -13,6 +13,7 @@ import (
 	"go.k6.io/k6/lib"
 	"go.k6.io/k6/lib/fsext"
 	"go.k6.io/k6/metrics"
+	"go.k6.io/k6/usage"
 )
 
 // Params contains all possible constructor parameters an output may need.
@@ -30,6 +31,7 @@ type Params struct {
 	ScriptOptions  lib.Options
 	RuntimeOptions lib.RuntimeOptions
 	ExecutionPlan  []lib.ExecutionStep
+	Usage          *usage.Usage
 }
 
 // TODO: make v2 with buffered channels?
@@ -66,6 +68,13 @@ type WithThresholds interface {
 	SetThresholds(map[string]metrics.Thresholds)
 }
 
+// WithArchive is an output that can receive the archive object in order
+// to upload it to the cloud.
+type WithArchive interface {
+	Output
+	SetArchive(archive *lib.Archive)
+}
+
 // WithTestRunStop is an output that can stop the test run mid-way through,
 // interrupting the whole test run execution if some internal condition occurs,
 // completely independently from the thresholds. It requires a callback function
